Before submitting a new issue, please check if a similar issue has already been filed.

### Issue subject
Briefly describe the issue here.


### Expected behaviour
Describe what should happen.


### Actual behaviour
Describe what happens instead. Please include the complete failure message.


### Steps to reproduce
Provide steps to let us know how we can reproduce this issue.


### Environment
Provide any relevant information about your setup, such as:
* Version of binance-connector-python
* Python version
* Operating system
